@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-#
 # Copyright Kevin Deldycke <kevin@deldycke.com> and contributors.
 # All Rights Reserved.
 #
@@ -21,12 +19,14 @@
 
 import logging
 
-from .bitbar import fix_environment
+from boltons.ecoutils import get_profile
+
+from .xbar import fix_environment
 
 # Canonical name of the CLI.
 CLI_NAME = "mpm"
 
-__version__ = "3.4.2"
+__version__ = "4.0.0"
 """ Examples of valid version strings according :pep:`440#version-scheme`:
 
 .. code-block:: python
@@ -40,6 +40,11 @@ __version__ = "3.4.2"
 """
 
 
+# Environment data.
+env_data = get_profile(scrub=True)
+
+
+# Initialize global logger.
 logger = logging.getLogger(__name__)
 
 
