@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-#
 # Copyright Kevin Deldycke <kevin@deldycke.com> and contributors.
 # All Rights Reserved.
 #
@@ -20,7 +18,7 @@
 import os
 from pathlib import Path
 from shutil import which
-from textwrap import indent, shorten
+from textwrap import dedent, indent, shorten
 
 import click
 from boltons.cacheutils import cachedproperty
@@ -29,43 +27,47 @@ from boltons.strutils import strip_ansi
 from boltons.typeutils import classproperty
 
 from . import logger
-from .bitbar import run
 from .platform import CURRENT_OS_ID
 from .version import parse_version
+from .xbar import run
 
 # Rendering format of CLI in JSON fields.
-CLI_FORMATS = frozenset(["plain", "fragments", "bitbar"])
+CLI_FORMATS = frozenset(["plain", "fragments", "bitbar", "xbar"])
 
 
 class CLIError(Exception):
 
-    """ An error occurred when running package manager CLI. """
+    """An error occurred when running package manager CLI."""
 
     def __init__(self, code, output, error):
-        """ The exception internally keeps the result of CLI execution. """
-        super(CLIError, self).__init__()
+        """The exception internally keeps the result of CLI execution."""
+        super().__init__()
         self.code = code
         self.output = output
         self.error = error
 
     def __str__(self):
-        """ Human-readable error. """
+        """Human-readable error."""
         margin = " " * 2
+        indented_output = indent(str(self.output), margin)
+        indented_error = indent(str(self.error), margin)
         return indent(
-            ("\nReturn code: {}\n" "Output:\n{}\n" "Error:\n{}").format(
-                self.code,
-                indent(str(self.output), margin),
-                indent(str(self.error), margin),
+            dedent(
+                f"""
+            Return code: {self.code}
+            Output:
+            {indented_output}
+            Error:
+            {indented_error}"""
             ),
             margin,
         )
 
     def __repr__(self):
-        return "<{}({}, {!r})>".format(
-            self.__class__.__name__,
-            self.code,
-            shorten(" ".join(self.error.split()), width=60, placeholder="(...)"),
+        error_excerpt = shorten(
+            " ".join(self.error.split()), width=60, placeholder="(...)"
         )
+        return f"<{self.__class__.__name__}({self.code}, {error_excerpt!r})>"
 
 
 class PackageManager:
@@ -89,7 +91,7 @@ class PackageManager:
     global_args = []
 
     # Tell the manager either to raise or continue on errors.
-    raise_on_cli_error = False
+    stop_on_error = False
 
     # Some managers have the ability to report or ignore packages
     # possessing their own auto-update mecanism.
@@ -134,25 +136,29 @@ class PackageManager:
     def cli_path(self):
         """Fully qualified path to the package manager CLI.
 
-        Automaticaly search the location of the CLI in the system.
+        Automaticaly search the location of the CLI in the system. Only checks
+        if the file exists. Its executability will be assessed later. See the
+        ``self.executable`` method below.
 
         Returns `None` if CLI is not found or is not a file.
         """
-        if not self.cli_name:
-            return None
-        env_path = ":".join(
-            self.cli_search_path + ["/usr/local/bin", os.environ.get("PATH")]
-        )
+        # Check if the path exist in any of the environment locations.
+        env_path = ":".join(self.cli_search_path + [os.getenv("PATH")])
         cli_path = which(self.cli_name, mode=os.F_OK, path=env_path)
         if not cli_path:
-            return None
-        cli_path = which(cli_path, mode=os.F_OK, path=env_path)
-
-        if cli_path:
-            cli_path = Path(cli_path).resolve(strict=True)
-            logger.debug(f"CLI found at {cli_path}")
-        else:
             logger.debug(f"{self.cli_name} CLI not found.")
+            return
+
+        # Check if path exist and is a file.
+        # Do not resolve symlink here. Some manager like Homebrew on Linux rely on some
+        # sort of synlink trickery to set environment variables.
+        cli_path = Path(cli_path)
+        if not cli_path.exists():
+            raise FileNotFoundError(f"{cli_path}")
+        elif not cli_path.is_file():
+            logger.warning(f"{cli_path} is not a file.")
+        else:
+            logger.debug(f"CLI found at {cli_path}")
 
         return cli_path
 
@@ -175,12 +181,12 @@ class PackageManager:
 
     @cachedproperty
     def supported(self):
-        """ Is the package manager supported on that platform? """
+        """Is the package manager supported on that platform?"""
         return CURRENT_OS_ID in self.platforms
 
     @cachedproperty
     def executable(self):
-        """ Is the package manager CLI can be executed by the current user? """
+        """Is the package manager CLI can be executed by the current user?"""
         if not self.cli_path:
             return False
         if not os.access(self.cli_path, os.X_OK):
@@ -190,7 +196,7 @@ class PackageManager:
 
     @cachedproperty
     def fresh(self):
-        """ Does the package manager match the version requirement? """
+        """Does the package manager match the version requirement?"""
         # Version is mandatory.
         if not self.version:
             return False
@@ -246,7 +252,7 @@ class PackageManager:
         if code and error:
             # Produce an exception and eventually raise it.
             exception = CLIError(code, output, error)
-            if self.raise_on_cli_error:
+            if self.stop_on_error:
                 raise exception
             # Accumulate errors.
             self.cli_errors.append(exception)
@@ -268,14 +274,14 @@ class PackageManager:
         return self.run(self.cli_path, args, dry_run=dry_run)
 
     def sync(self):
-        """ Refresh local manager metadata from remote repository. """
+        """Refresh local manager metadata from remote repository."""
         if self.sync.__func__.__qualname__ == PackageManager.sync.__qualname__:
             logger.warning(f"Sync not implemented for {self.id}.")
             return
         logger.info(f"Sync {self.id} package info...")
 
     def cleanup(self):
-        """ Remove left-overs and unused packages. """
+        """Remove left-overs and unused packages."""
         if self.cleanup.__func__.__qualname__ == PackageManager.cleanup.__qualname__:
             logger.warning(f"Cleanup not implemented for {self.id}.")
             return
@@ -297,7 +303,9 @@ class PackageManager:
         package ID, name, version and a boolean indicating if the match is
         exact or partial.
         """
-        raise NotImplementedError
+        if self.search.__func__.__qualname__ == PackageManager.search.__qualname__:
+            logger.warning(f"Search not implemented for {self.id}.")
+            return {}
 
     @property
     def outdated(self):
@@ -310,15 +318,15 @@ class PackageManager:
         raise NotImplementedError
 
     def upgrade_cli(self, package_id=None):
-        """ Return a bash-compatible full-CLI to upgrade a package. """
+        """Return a shell-compatible full-CLI to upgrade a package."""
         raise NotImplementedError
 
     def upgrade(self, package_id=None, dry_run=False):
-        """ Perform the upgrade of the provided package to latest version. """
+        """Perform the upgrade of the provided package to latest version."""
         return self.run(self.upgrade_cli(package_id), dry_run=dry_run)
 
     def upgrade_all_cli(self):
-        """ Return a bash-compatible full-CLI to upgrade all packages. """
+        """Return a shell-compatible full-CLI to upgrade all packages."""
         raise NotImplementedError
 
     def upgrade_all(self, dry_run=False):
@@ -348,8 +356,13 @@ class PackageManager:
 
         * ``plain`` returns a simple string
         * ``fragments`` returns a list of strings
-        * ``bitbar`` returns a CLI with parameters formatted into the bitbar
-        dialect.
+        * ``xbar`` (or ``bitbar``) returns a CLI with parameters formatted into
+        the xbar dialect
+
+        ..warning:
+
+            ``bitbar`` is deprecated but is provided as temporary alias to
+            ``xbar`` to provide a smooth transition to the rebooted project.
         """
         assert isinstance(cmd, list)
         assert cli_format in CLI_FORMATS
@@ -361,13 +374,13 @@ class PackageManager:
         if cli_format == "plain":
             return " ".join(cmd)
 
-        # Renders the CLI into BitBar dialect.
-        bitbar_cli = ""
+        # Renders the CLI into xbar dialect.
+        xbar_cli = ""
         for index, param in enumerate(cmd):
             if index == 0:
-                bitbar_cli += "bash={}".format(param)
+                xbar_cli += f"shell={param}"
             else:
                 if "=" in param:
-                    param = '\\"{}\\"'.format(param)
-                bitbar_cli += " param{}={}".format(index, param)
-        return bitbar_cli
+                    param = f'\\"{param}\\"'
+                xbar_cli += f" param{index}={param}"
+        return xbar_cli
