@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-#
 # Copyright Kevin Deldycke <kevin@deldycke.com> and contributors.
 # All Rights Reserved.
 #
@@ -34,9 +32,10 @@ import tomlkit
 from boltons.cacheutils import LRI, cached
 from boltons.strutils import complement_int_list, int_ranges_from_int_list, strip_ansi
 from cli_helpers.tabular_output import TabularOutputFormatter
+from click_help_colors import HelpColorsCommand, HelpColorsGroup, version_option
 from simplejson import dumps as json_dumps
 
-from . import __version__, logger, CLI_NAME
+from . import CLI_NAME, __version__, env_data, logger
 from .base import CLI_FORMATS, CLIError, PackageManager
 from .managers import pool
 from .platform import CURRENT_OS_ID, WINDOWS, os_label
@@ -109,7 +108,7 @@ def json(data):
 
 
 def print_table(header_defs, rows, sort_key=None):
-    """ Utility to print a table and sort its content. """
+    """Utility to print a table and sort its content."""
     # Do not print anything, not even table headers if no rows.
     if not rows:
         return
@@ -154,17 +153,17 @@ def print_table(header_defs, rows, sort_key=None):
 
 
 def print_stats(data):
-    """ Print statistics. """
+    """Print statistics."""
     manager_stats = {infos["id"]: len(infos["packages"]) for infos in data.values()}
     total_installed = sum(manager_stats.values())
     per_manager_totals = ", ".join(
         [
-            "{}: {}".format(k, v)
+            f"{k}: {v}"
             for k, v in sorted(manager_stats.items(), key=itemgetter(1), reverse=True)
         ]
     )
     if per_manager_totals:
-        per_manager_totals = " ({})".format(per_manager_totals)
+        per_manager_totals = f" ({per_manager_totals})"
     plural = "s" if total_installed > 1 else ""
     click.echo(f"{total_installed} package{plural} total{per_manager_totals}.")
 
@@ -201,7 +200,7 @@ class timeit:
 @click.option(
     "-m",
     "--manager",
-    type=click.Choice(pool()),
+    type=click.Choice(pool(), case_sensitive=False),
     multiple=True,
     help="Restrict sub-command to a subset of package managers. Repeat to "
     "select multiple managers. Defaults to all.",
@@ -209,7 +208,7 @@ class timeit:
 @click.option(
     "-e",
     "--exclude",
-    type=click.Choice(pool()),
+    type=click.Choice(pool(), case_sensitive=False),
     multiple=True,
     help="Exclude a package manager. Repeat to exclude multiple managers. "
     "Defaults to none.",
@@ -224,14 +223,14 @@ class timeit:
 @click.option(
     "-o",
     "--output-format",
-    type=click.Choice(sorted(RENDERING_MODES)),
+    type=click.Choice(sorted(RENDERING_MODES), case_sensitive=False),
     default="fancy_grid",
     help="Rendering mode of the output. Defaults to fancy-grid.",
 )
 @click.option(
     "-s",
     "--sort-by",
-    type=click.Choice(SORTABLE_FIELDS),
+    type=click.Choice(SORTABLE_FIELDS, case_sensitive=False),
     default="manager_id",
     help="Sort results. Defaults to manager_id.",
 )
@@ -247,11 +246,18 @@ class timeit:
 )
 @click.option(
     "--stop-on-error/--continue-on-error",
-    default=True,
-    help="Stop right "
-    "away or continue operations on manager CLI error. Defaults to stop.",
+    default=False,
+    help="Stop right away or continue operations on manager CLI error. Defaults to "
+    "continue.",
+)
+@version_option(
+    version=__version__,
+    prog_name=CLI_NAME,
+    version_color="green",
+    prog_name_color="white",
+    message=f"%(prog)s %(version)s\n{env_data}",
+    message_color="bright_black",
 )
-@click.version_option(__version__)
 @click.pass_context
 def cli(
     ctx,
@@ -264,7 +270,7 @@ def cli(
     time,
     stop_on_error,
 ):
-    """ CLI for multi-package manager upgrades. """
+    """CLI for multi-package manager upgrades."""
     # TODO: merge CLI parameters and config file here.
     # See: https://github.com/kdeldycke/meta-package-manager/issues/66
 
@@ -284,7 +290,7 @@ def cli(
     # Apply manager-level options.
     for m_obj in target_managers:
         # Does the manager should raise on error or not.
-        m_obj.raise_on_error = stop_on_error
+        m_obj.stop_on_error = stop_on_error
         # Should we include auto-update packages or not?
         m_obj.ignore_auto_updates = ignore_auto_updates
 
@@ -369,9 +375,7 @@ def managers(ctx):
         # Build up the CLI path column content.
         cli_infos = "{}  {}".format(
             OK if manager.cli_path else KO,
-            manager.cli_path
-            if manager.cli_path
-            else "{!r} not found".format(manager.cli_name),
+            manager.cli_path if manager.cli_path else f"{manager.cli_name!r} not found",
         )
 
         # Build up the version column content.
@@ -379,9 +383,9 @@ def managers(ctx):
         if manager.executable:
             version_infos = OK if manager.fresh else KO
             if manager.version:
-                version_infos += "  {}".format(manager.version)
+                version_infos += f"  {manager.version}"
                 if not manager.fresh:
-                    version_infos += " {}".format(manager.requirement)
+                    version_infos += f" {manager.requirement}"
 
         table.append(
             [
@@ -412,7 +416,7 @@ def managers(ctx):
 @click.pass_context
 @timeit()
 def sync(ctx):
-    """ Sync local package metadata and info from external sources. """
+    """Sync local package metadata and info from external sources."""
     active_managers = ctx.obj["active_managers"]
 
     for manager in active_managers:
@@ -423,7 +427,7 @@ def sync(ctx):
 @click.pass_context
 @timeit()
 def cleanup(ctx):
-    """ Cleanup local data and temporary artifacts. """
+    """Cleanup local data and temporary artifacts."""
     active_managers = ctx.obj["active_managers"]
 
     for manager in active_managers:
@@ -434,7 +438,7 @@ def cleanup(ctx):
 @click.pass_context
 @timeit()
 def installed(ctx):
-    """ List all packages installed on the system from all managers. """
+    """List all packages installed on the system from all managers."""
     active_managers = ctx.obj["active_managers"]
     output_format = ctx.obj["output_format"]
     sort_by = ctx.obj["sort_by"]
@@ -507,7 +511,7 @@ def installed(ctx):
 @click.pass_context
 @timeit()
 def search(ctx, extended, exact, query):
-    """ Search packages from all managers. """
+    """Search packages from all managers."""
     active_managers = ctx.obj["active_managers"]
     output_format = ctx.obj["output_format"]
     sort_by = ctx.obj["sort_by"]
@@ -551,7 +555,7 @@ def search(ctx, extended, exact, query):
 
                 for match_start in occurrences:
                     match_end = match_start + len(part) - 1
-                    ranges.add("{}-{}".format(match_start, match_end))
+                    ranges.add(f"{match_start}-{match_end}")
 
         # Reduce index ranges, compute complement ranges, transform them to
         # list of integers.
@@ -604,7 +608,7 @@ def search(ctx, extended, exact, query):
 @click.option(
     "-c",
     "--cli-format",
-    type=click.Choice(CLI_FORMATS),
+    type=click.Choice(CLI_FORMATS, case_sensitive=False),
     default="plain",
     help="Format of CLI fields in JSON output. Defaults to plain.",
 )
@@ -697,7 +701,7 @@ def outdated(ctx, cli_format):
 @click.pass_context
 @timeit()
 def upgrade(ctx, dry_run):
-    """ Perform a full package upgrade on all available managers. """
+    """Perform a full package upgrade on all available managers."""
     active_managers = ctx.obj["active_managers"]
 
     for manager in active_managers:
@@ -750,7 +754,7 @@ def backup(ctx, toml_output):
     # Initialize the TOML structure.
     doc = tomlkit.document()
     # Leave some metadata as comment.
-    doc.add(tomlkit.comment("Generated by {} {}.".format(CLI_NAME, __version__)))
+    doc.add(tomlkit.comment(f"Generated by {CLI_NAME} {__version__}."))
     doc.add(tomlkit.comment("Timestamp: {}.".format(datetime.now().isoformat())))
 
     installed_data = {}
@@ -771,7 +775,7 @@ def backup(ctx, toml_output):
         )
         for package_id, package_version in pkg_data:
             # Version specifier is inspired by Poetry.
-            manager_section.add(package_id, "^{}".format(package_version))
+            manager_section.add(package_id, f"^{package_version}")
         if pkg_data:
             doc.add(manager.id, manager_section)
 
@@ -803,9 +807,7 @@ def restore(ctx, toml_files):
         doc = tomlkit.parse(toml_input.read())
 
         # List unrecognized sections.
-        ignored_sections = [
-            "[{}]".format(section) for section in doc if section not in pool()
-        ]
+        ignored_sections = [f"[{section}]" for section in doc if section not in pool()]
         if ignored_sections:
             plural = "s" if len(ignored_sections) > 1 else ""
             sections = ", ".join(ignored_sections)
