@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-#
 # Copyright Kevin Deldycke <kevin@deldycke.com> and contributors.
 # All Rights Reserved.
 #
@@ -22,37 +20,42 @@
 
 from boltons.iterutils import flatten
 
+from . import CLI_NAME
 from .managers import pool
 from .platform import ALL_OS_LABELS
-from . import CLI_NAME
 
 # Format: label name, color, optional description.
 LABELS = [
     (
-        "BitBar plugin",
+        "🔌 BitBar plugin",
         "#fef2c0",
         "Plugin code, documentation or features related to BitBar",
     ),
-    ("bug", "#d73a4a", "Something isn't working, or a fix is proposed"),
-    ("CI/CD", "#dbca13", "Tests, automation and management of the project"),
     (
-        "documentation",
+        "🔌 xbar plugin",
+        "#fef2c0",
+        "Plugin code, documentation or features related to xbar",
+    ),
+    ("🐛 bug", "#d73a4a", "Something isn't working, or a fix is proposed"),
+    ("🔩 CI/CD", "#dbca13", "Tests, automation and management of the project"),
+    (
+        "📗 documentation",
         "#006b75",
         "Update to non-code (manual, readme, tutorial, docstrings, ...) and "
         "its generation",
     ),
-    ("duplicate", "#cfd3d7", "This issue or pull request already exists"),
-    ("enhancement", "#84b6eb", "Improvement or change of an existing feature"),
+    ("🔄 duplicate", "#cfd3d7", "This issue or pull request already exists"),
+    ("✨ enhancement", "#84b6eb", "Improvement or change of an existing feature"),
     (
-        "feature request",
+        "🆕 feature request",
         "#fbca04",
         "Something not existing yet that need to be implemented",
     ),
-    ("good first issue", "#7057ff", "A place for newcomers to start contributing"),
-    ("help wanted", "#008672", "Extra attention is needed"),
-    ("can't reproduce", "#fec1c1", "Root cause unlikely to come from the project"),
-    ("question", "#d876e3", "Further information is requested"),
-    ("wont do/fix", "#eeeeee", "This will not be worked on"),
+    ("🌱 good first issue", "#7057ff", "A place for newcomers to start contributing"),
+    ("🆘 help wanted", "#008672", "Extra attention is needed"),
+    ("🎲 can't reproduce", "#fec1c1", "Root cause unlikely to come from the project"),
+    ("❓ question", "#d876e3", "Further information is requested"),
+    ("🚫 wont do/fix", "#eeeeee", "This will not be worked on"),
 ]
 
 
@@ -67,14 +70,17 @@ MANAGER_GROUPS = {
     "npm-like": {"npm", "yarn"},
 }
 
-# Define some colors.
+
+# Define generated labels prefixes and colors.
+PLATFORM_PREFIX = "🖥 platform: "
 PLATFORM_COLOR = "#bfd4f2"
+MANAGER_PREFIX = "📦 manager: "
 MANAGER_COLOR = "#bfdadc"
 
 
 # Create one label per platform.
 for platform_id in ALL_OS_LABELS:
-    label_id = "platform: {}".format(platform_id)
+    label_id = f"{PLATFORM_PREFIX}{platform_id}"
     LABELS.append((label_id, PLATFORM_COLOR, platform_id))
     PLATFORM_LABELS[platform_id] = label_id
 
@@ -82,7 +88,7 @@ for platform_id in ALL_OS_LABELS:
 # Create one label per manager. Add mpm as its own manager.
 non_grouped_managers = set(pool()) - set(flatten(MANAGER_GROUPS.values())) | {CLI_NAME}
 for manager_id in non_grouped_managers:
-    label_id = "manager: {}".format(manager_id)
+    label_id = f"{MANAGER_PREFIX}{manager_id}"
     LABELS.append((label_id, MANAGER_COLOR, manager_id))
     if manager_id != CLI_NAME:
         MANAGER_LABELS[manager_id] = label_id
@@ -90,7 +96,7 @@ for manager_id in non_grouped_managers:
 
 # Add labels for grouped managers.
 for group_label, manager_ids in MANAGER_GROUPS.items():
-    label_id = "manager: {}".format(group_label)
+    label_id = f"{MANAGER_PREFIX}{group_label}"
     LABELS.append((label_id, MANAGER_COLOR, ", ".join(sorted(manager_ids))))
     for manager_id in manager_ids:
         MANAGER_LABELS[manager_id] = label_id
