@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-#
 # Copyright Kevin Deldycke <kevin@deldycke.com> and contributors.
 # All Rights Reserved.
 #
@@ -81,7 +79,7 @@ class APT(PackageManager):
             Building dependency tree...
             Reading state information...
         """
-        super(APT, self).sync()
+        super().sync()
         self.run_cli(self.global_args, "update", "--quiet")
 
     @property
@@ -193,7 +191,7 @@ class APT(PackageManager):
         search_args = ["--names-only"]
         if exact:
             # Realy on apt regexp support to speed-up exact match.
-            query = "^{}$".format(query)
+            query = f"^{query}$"
         # Extended search are always non-exact.
         elif extended:
             # Include full description in extended search to check up the match
@@ -274,6 +272,6 @@ class APT(PackageManager):
 
             ► sudo apt-get -y autoremove
         """
-        super(APT, self).cleanup()
+        super().cleanup()
         self.run("sudo", self.cli_path, self.global_args, "-y", "autoremove")
         self.run("sudo", self.cli_path, self.global_args, "clean")
