@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-#
 # Copyright Kevin Deldycke <kevin@deldycke.com> and contributors.
 # All Rights Reserved.
 #
@@ -260,5 +258,5 @@ class Yarn(PackageManager):
 
         See: https://yarnpkg.com/cli/cache/clean
         """
-        super(Yarn, self).cleanup()
+        super().cleanup()
         self.run_cli(self.global_args, "cache", "clean", "--all")
