@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-#
 # Copyright Kevin Deldycke <kevin@deldycke.com> and contributors.
 # All Rights Reserved.
 #
@@ -29,10 +27,10 @@ from boltons.strutils import strip_ansi
 from boltons.tbutils import ExceptionInfo
 from click.testing import CliRunner
 
-from ..bitbar import run as bitbar_run
-from ..cli import cli
 from .. import CLI_NAME
+from ..cli import cli
 from ..platform import is_linux, is_macos, is_windows
+from ..xbar import run as xbar_run
 
 """ Fixtures, configuration and helpers for tests. """
 
@@ -97,27 +95,25 @@ unless_windows = pytest.mark.skipif(not is_windows(), reason="Windows required")
 """ Pytest mark to skip a test unless it is run on a Windows system. """
 
 
-def print_cli_output(cmd, output):
-    """ Simulate CLI output. Used to print debug traces in test results. """
+def print_cli_output(cmd, output=None, error=None, error_code=None):
+    """Simulate CLI output. Used to print debug traces in test results."""
     print("\n► {}".format(click.style(" ".join(cmd), fg="white")))
+    margin = " " * 2
     if output:
-        print(indent(output, "  "))
+        print(indent(output, margin))
+    if error:
+        print(indent(click.style(error, fg="red"), margin))
+    if error_code is not None:
+        print(click.style(f"{margin}Return code: {error_code}", fg="yellow"))
 
 
 def run_cmd(*args):
     """Run a system command, print output and return results.
 
-    Relies on robust ``run`` function implemented in BitBar plugin.
+    Relies on robust ``run`` function implemented in xbar plugin.
     """
-    code, output, error = bitbar_run(*args)
-
-    print_cli_output(args, output)
-
-    # Print some more debug info.
-    print(click.style("Return code: {}".format(code), fg="yellow"))
-    if error:
-        print(indent(click.style(error, fg="red"), "  "))
-
+    code, output, error = xbar_run(*args)
+    print_cli_output(args, output, error, code)
     return code, output, error
 
 
@@ -130,15 +126,9 @@ def runner():
 
 @pytest.fixture
 def invoke(runner):
-    """ Executes Click's CLI, print output and return results. """
-
-    # XXX Python 3-only function signature.
-    # TODO: Use the commented signature below once we drop special Python 2.7
-    # unittest for BitBar.
-    # def _run(*args, color=False):
-    def _run(*args, **kwargs):
-        color = kwargs.get("color", False)
+    """Executes Click's CLI, print output and return results."""
 
+    def _run(*args, color=False):
         # We allow for nested iterables and None values as args for
         # convenience. We just need to flatten and filters them out.
         args = list(filter(None.__ne__, flatten(args)))
@@ -151,10 +141,10 @@ def invoke(runner):
         result.stdout_bytes = strip_ansi(result.stdout_bytes)
         result.stderr_bytes = strip_ansi(result.stderr_bytes)
 
-        print_cli_output([CLI_NAME] + args, result.output)
+        print_cli_output(
+            [CLI_NAME] + args, result.output, result.stderr, result.exit_code
+        )
 
-        # Print some more debug info.
-        print(result)
         if result.exception:
             print(ExceptionInfo.from_exc_info(*result.exc_info).get_formatted())
 
