@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-#
 # Copyright Kevin Deldycke <kevin@deldycke.com> and contributors.
 # All Rights Reserved.
 #
@@ -26,10 +24,10 @@ import simplejson as json
 from boltons.iterutils import flatten
 from yaml import Loader, load
 
-from ..labels import MANAGER_LABELS, PLATFORM_LABELS
+from ..labels import MANAGER_LABELS, MANAGER_PREFIX, PLATFORM_LABELS, PLATFORM_PREFIX
 from ..managers import pool
 from ..platform import OS_DEFINITIONS, os_label
-from .conftest import MANAGER_IDS
+from .conftest import MANAGER_IDS, unless_linux
 
 """ Test all non-code artifacts depending on manager definitions.
 
@@ -59,11 +57,16 @@ def test_changelog():
             entry = match.groupdict()
             assert entry["category"]
             assert set(entry["category"].split(",")).issubset(
-                flatten([MANAGER_IDS, OS_DEFINITIONS.keys(), "mpm", "bitbar"])
+                flatten([MANAGER_IDS, OS_DEFINITIONS.keys(), "mpm", "bitbar", "xbar"])
             )
 
 
+@unless_linux
 def test_labeller_rules():
+    """This covers the dynamic production of labels by GitHub action. As such it
+    only targets Linux. See: https://github.com/kdeldycke/meta-package-manager/blob
+    /bd666e291c783fe480015c9aae3beab19b12774c/.github/workflows/labels.yaml#L14
+    """
 
     # Extract list of canonically defined labels.
     with PROJECT_ROOT.joinpath(".github/labels.json").resolve().open() as doc:
@@ -78,10 +81,10 @@ def test_labeller_rules():
     canonical_managers = {
         lbl
         for lbl in canonical_labels
-        if lbl.startswith("manager: ") and "mpm" not in lbl
+        if lbl.startswith(MANAGER_PREFIX) and "mpm" not in lbl
     }
     canonical_platforms = {
-        lbl for lbl in canonical_labels if lbl.startswith("platform: ")
+        lbl for lbl in canonical_labels if lbl.startswith(PLATFORM_PREFIX)
     }
     assert canonical_managers
     assert canonical_platforms
@@ -114,14 +117,14 @@ def test_labeller_rules():
         {
             label: count
             for label, count in rules_labels.items()
-            if label.startswith("manager: ")
+            if label.startswith(MANAGER_PREFIX)
         }
     )
     rules_platforms = Counter(
         {
             label: count
             for label, count in rules_labels.items()
-            if label.startswith("platform: ")
+            if label.startswith(PLATFORM_PREFIX)
         }
     )
 
