@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-#
 # Copyright Kevin Deldycke <kevin@deldycke.com> and contributors.
 # All Rights Reserved.
 #
@@ -81,7 +79,7 @@ def test_os_definitions():
         assert label in ALL_OS_LABELS
         # OS identification function.
         assert isinstance(os_flag, bool)
-        os_id_func_name = "is_{}".format(os_id)
+        os_id_func_name = f"is_{os_id}"
         assert os_id_func_name in globals()
         os_id_func = globals()[os_id_func_name]
         assert isinstance(os_id_func, FunctionType)
@@ -105,11 +103,12 @@ def test_os_label():
 
 
 def test_blacklisted_manager():
-    """ Check all managers are accounted for on each platforms. """
+    """Check all managers are accounted for on each platforms."""
+    # TODO: Use that blacklist to generate readme.rst's support table?
     blacklists = {
-        LINUX: {"brew", "cask", "mas"},
+        LINUX: {"cask", "mas"},
         MACOS: {"apt", "flatpak", "opkg", "snap"},
-        WINDOWS: {"apt", "cask", "brew", "flatpak", "mas", "opkg", "snap"},
+        WINDOWS: {"apt", "brew", "cask", "flatpak", "mas", "opkg", "snap"},
     }
     blacklist = blacklists[current_os()[0]]
     # List of supported managers on the current platform.
